@@ -12,6 +12,9 @@ test -d $DIR || { echo "Directory $DIR doesn't exist"; exit 2; }
 TARBALL="$PWD/$DIR/clamav-$VERS.tar.gz"
 test -f $TARBALL || { echo "Tarball $TARBALL doesn't exist"; exit 3; }
 
+UNRAR_CONF="$(realpath ${0%split-tarball.sh}libclamunrar-configure.ac)"
+test -f $UNRAR_CONF || { echo "libclamunrar $UNRAR_CONF doesn't exist"; exit 1; }
+
 TEMP=`mktemp -d __splitXXXXXX` || { echo "Cannot create temporary directory"; exit 2; }
 echo "Temporary directory is $TEMP"
 cd $TEMP || exit 3;
@@ -33,9 +36,6 @@ echo "Preparing dfsg package"
 cd clamav-$VERS+dfsg
 # remove win32 stuff, doesn't make sense to ship it
 rm -rf win32
-sed -i 's/ win32//' Makefile.am Makefile.in
-sed -i 's@libclammspack/config.h:libclammspack/config.h.in@@' configure.ac
-find shared -name '*.la' -o -name '*.lo' -o -name Makefile  -exec rm {} \;
 # cleanup llvm
 set -- libclamav/c++/llvm/utils/lit/lit/*.pyc
 if [ -f "$1" ] ; then
@@ -46,62 +46,22 @@ rm -rf libclamav/c++/llvm/tools libclamav/c++/llvm/unittests \
  libclamav/c++/llvm/bindings libclamav/c++/llvm/bindings/ocaml \
  libclamav/c++/llvm/examples libclamav/c++/llvm/runtime \
  libclamav/c++/llvm/projects libclamav/c++/llvm/test
-# remove llvm, we build with the system version
-#rm -rf libclamav/c++/llvm
+
+# That CR/LF conversation causes major pain.
+rm .gitattributes
 cp -R libclamunrar_iface $UNRARDIR
-cp libclamav/Makefile.am $UNRARDIR/libclamunrar_iface
-mv libclamunrar $UNRARDIR
-cp -R m4/ $UNRARDIR
-cp -R config/ $UNRARDIR
-cp configure.ac $UNRARDIR
-cp platform.h.in $UNRARDIR
-cp COPYING{,.unrar,.LGPL} $UNRARDIR
+
+# XXX Add the libclamunrar bits
+
 cd ../
 tar -cJf $DFSGPKG --numeric-owner clamav-$VERS+dfsg/
-cd $UNRARDIR
-echo "Preparing unrar package"
-# The sed sorcery below makes sure that the AC_CONFIG_FILES in the unrar package looks
-# like:
-# AC_CONFIG_FILES([
-# libclamunrar_iface/Makefile
-# Makefile
-# platform.h
-# ])
-# It also removes ltdl, and renames the AC_CONFIG_SRCDIR parameter to an
-# existing file.
-sed -i '/AC_CONFIG_FILES/,/])/ {
-/^AC_CONFIG_FILES(\[$/p
-s/^clamscan\/Makefile/libclamunrar_iface\/Makefile/p
-/^Makefile/p
-/^platform.h/p
-/^])/p
-d
-}
-/LTDL/d
-/ltdl/d
-/.*m4\/reorganization\/llvm.m4/d
-/.*m4\/reorganization\/libmspack.m4/d
-/AC_OUTPUT(\[.*Makefile/d
-s/clamscan\/clamscan.c/libclamunrar_iface\/unrar_iface.cpp/
-' configure.ac
-cat <<EOF >Makefile.am &&
-ACLOCAL_AMFLAGS=-I m4
-DISTCLEANFILES = target.h
-SUBDIRS = libclamunrar_iface
-EOF
+echo "missing clamunrar, you need to look at that."
+exit 0
 
-# The complete Makefile.am from libclamav/Makefile.am is huge and we
-# only need the libclamunrar pieces. If we keep everything it will
-# break for instance due to missing c++ folder or something else.
-# The UNRAR block is the first one followed by LLVM so try to remove
-# everything after the LLVM block so we should have enough to get the
-# complete libclamunrar compiled.
-sed -i '/if ENABLE_LLVM/,$d' libclamunrar_iface/Makefile.am
-
-autoreconf
-rm -r autom4te.cache
-cd ..
-tar -cJf $UNRARPKG --numeric-owner libclamunrar-$VERS/
+#cd $UNRARDIR
+#echo "Preparing unrar package"
+#cd ..
+#tar -cJf $UNRARPKG --numeric-owner libclamunrar-$VERS/
 
 printf "Test archives?"
 read yes
